.. module:: streamsets
.. _welcome:

Welcome
=======
|

.. toctree::
   :maxdepth: 3
   :hidden:

   welcome/overview
   welcome/installation
   welcome/authentication
   welcome/release_notes
   welcome/known_issues
   welcome/examples
